/********************
 *
 * gNiNumDen.cpp
 *
 *  dialog to obtain numerator and denominator values for completion
 *  items.
 *
 *  This file is part of Prozect.
 *  Copyright (C) 2003 Robert T. Miller
 *  
 *  Prozect is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  Prozect is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with Prozect; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *  
 *******************/
#include "moc_gNiNumDen.cpp"

//#include "debug.h"
#include <qlabel.h>
#include <qmessagebox.h>

getNiNumDen::getNiNumDen(QWidget * parent=0, const char * name=0, bool modal=false, WFlags f=0 ) 
  : QDialog(parent, name, modal, f) {
  
  setCaption("Numeric Item details");

  gnd_tb = new QToolBar("NItem",(QMainWindow*)parent,this);
  gnd_tb->setHorizontalStretchable(true);

  gnd_num_e = new QLineEdit(gnd_tb,"numerator");
  connect(gnd_num_e, SIGNAL(returnPressed()),this,SLOT(slotGndNumLErtn()));

  new QLabel(" / ",gnd_tb);
  gnd_den_e = new QLineEdit(gnd_tb,"denominator");
  connect(gnd_den_e, SIGNAL(returnPressed()),this,SLOT(slotGndDenLErtn()));

}

getNiNumDen::~getNiNumDen() {
  delete gnd_num_e;
  delete gnd_den_e;
  delete gnd_tb;
}

bool getNiNumDen::query(int *num,int *den) {

  gnd_num_e->setText(QString::number(*num));
  gnd_den_e->setText(QString::number(*den));

  gnd_num_e->setFocus();

  if (exec()) {

    bool ok=false;
    int tnum, tden;

    tnum = (int) gnd_num_e->text().toUInt(&ok);
    if (!ok) {
      QString txt = "numerator not positive integer: ";
      txt += gnd_num_e->text();
      QMessageBox::about(this,"Numerator error",txt);
      return false;
    }
  
    tden = (int) gnd_den_e->text().toUInt(&ok);
    if (!ok && den) {
      QString txt = "denominator not non-zero positive integer: ";
      txt += gnd_den_e->text();
      QMessageBox::about(this,"Denominator error",txt);
      return false;
    }
    *num = tnum;
    *den = tden;
    return true;
  } else 
    return false;
}

void getNiNumDen::slotGndNumLErtn() {
  gnd_den_e->setFocus();
}

void getNiNumDen::slotGndDenLErtn() {
  accept();
}


  
